[−][src]Struct linux_io_uring::opcode::PollAdd
Poll the fd specified in the submission queue entry for the events specified in the poll_events field.
Unlike poll or epoll without EPOLLONESHOT, this interface always works in one shot mode.
That is, once the poll operation is completed, it will have to be resubmitted.
Methods
impl PollAdd[src]
pub fn new(fd: Target, flags: i16) -> Self[src]
The bits that may be set in flags are defined in <poll.h>,
and documented in poll (2).
impl PollAdd[src]